Enum tina::image::error::ImageFormatHint
#[non_exhaustive]
pub enum ImageFormatHint {
Exact(ImageFormat),
Name(String),
PathExtension(PathBuf),
Unknown,
}Expand description
A best effort representation for image formats.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Exact(ImageFormat)
The format is known exactly.
Name(String)
The format can be identified by a name.
PathExtension(PathBuf)
A common path extension for the format is known.
Unknown
The format is not known or could not be determined.