pub struct StreamInfoStreamReply {
    pub last_generated_id: String,
    pub radix_tree_keys: usize,
    pub groups: usize,
    pub length: usize,
    pub first_entry: StreamId,
    pub last_entry: StreamId,
}
Reply type used with xinfo_stream command, containing general information about the stream stored at the specified key.

The very first and last IDs in the stream are shown, in order to give some sense about what is the stream content.

Fields

last_generated_id: String

The last generated ID that may not be the same as the last entry ID in case some entry was deleted.

radix_tree_keys: usize

Details about the radix tree representing the stream mostly useful for optimization and debugging tasks.

groups: usize

The number of consumer groups associated with the stream.

length: usize

Number of elements of the stream.

first_entry: StreamId

The very first entry in the stream.

last_entry: StreamId

The very last entry in the stream.