#[non_exhaustive]pub struct Paths {
pub paths: BTreeMap<String, PathItem, Global>,
}Expand description
Implements OpenAPI Paths Object.
Holds relative paths to matching endpoints and operations. The path is appended to the url
from Server object to construct a full url for endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.paths: BTreeMap<String, PathItem, Global>Implementations
impl Paths
impl Paths
pub fn get_path_item<P>(&self, path: P) -> Option<&PathItem>where
P: AsRef<str>,
pub fn get_path_item<P>(&self, path: P) -> Option<&PathItem>where P: AsRef<str>,
Return Option of reference to PathItem by given relative path P if one exists
in Paths::paths map. Otherwise will return None.
Examples
Get user path item.
let path_item = paths.get_path_item("/api/v1/user");pub fn get_path_operation<P>(
&self,
path: P,
item_type: PathItemType
) -> Option<&Operation>where
P: AsRef<str>,
pub fn get_path_operation<P>( &self, path: P, item_type: PathItemType ) -> Option<&Operation>where P: AsRef<str>,
Return Option of reference to Operation from map of paths or None if not found.
- First will try to find
PathItemby given relative pathPe.g."/api/v1/user". - Then tries to find
OperationfromPathItem’s operations by givenPathItemType.
Examples
Get user operation from paths.
let operation = paths.get_path_operation("/api/v1/user", PathItemType::Get);Trait Implementations
impl<'de> Deserialize<'de> for Paths
impl<'de> Deserialize<'de> for Paths
fn deserialize<__D>(
__deserializer: __D
) -> Result<Paths, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>( __deserializer: __D ) -> Result<Paths, <__D as Deserializer<'de>>::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl From<Paths> for PathsBuilder
impl From<Paths> for PathsBuilder
fn from(value: Paths) -> PathsBuilder
fn from(value: Paths) -> PathsBuilder
Converts to this type from the input type.
impl From<PathsBuilder> for Paths
impl From<PathsBuilder> for Paths
fn from(value: PathsBuilder) -> Paths
fn from(value: PathsBuilder) -> Paths
Converts to this type from the input type.
impl Serialize for Paths
impl Serialize for Paths
fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>( &self, __serializer: __S ) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where __S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for Paths