Struct tina::utoipa::openapi::schema::Components
#[non_exhaustive]pub struct Components {
pub schemas: BTreeMap<String, RefOr<Schema>, Global>,
pub responses: BTreeMap<String, RefOr<Response>, Global>,
pub security_schemes: BTreeMap<String, SecurityScheme, Global>,
}Expand description
Implements OpenAPI Components Object which holds supported reusable objects.
Components can hold either reusable types themselves or references to other reusable types.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schemas: BTreeMap<String, RefOr<Schema>, Global>Map of reusable OpenAPI Schema Objects.
responses: BTreeMap<String, RefOr<Response>, Global>Map of reusable response name, to OpenAPI Response Objects or OpenAPI References to OpenAPI Response Objects.
security_schemes: BTreeMap<String, SecurityScheme, Global>Map of reusable OpenAPI Security Scheme Objects.
Implementations
impl Components
impl Components
pub fn new() -> Components
pub fn new() -> Components
Construct a new Components.
pub fn add_security_scheme<N, S>(&mut self, name: N, security_schema: S)where
N: Into<String>,
S: Into<SecurityScheme>,
pub fn add_security_scheme<N, S>(&mut self, name: N, security_schema: S)where N: Into<String>, S: Into<SecurityScheme>,
Add SecurityScheme to Components
Accepts two arguments where first is the name of the SecurityScheme. This is later when
referenced by SecurityRequirements. Second parameter is the SecurityScheme.
pub fn add_security_schemes_from_iter<I, N, S>(&mut self, schemas: I)where
I: IntoIterator<Item = (N, S)>,
N: Into<String>,
S: Into<SecurityScheme>,
pub fn add_security_schemes_from_iter<I, N, S>(&mut self, schemas: I)where I: IntoIterator<Item = (N, S)>, N: Into<String>, S: Into<SecurityScheme>,
Add iterator of SecuritySchemes to Components.
Accepts two arguments where first is the name of the SecurityScheme. This is later when
referenced by SecurityRequirements. Second parameter is the SecurityScheme.